# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: protobuf-definitions/horizon/H3DProtoBuf.proto
# Protobuf Python Version: 6.33.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    33,
    0,
    '',
    'protobuf-definitions/horizon/H3DProtoBuf.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n.protobuf-definitions/horizon/H3DProtoBuf.proto\"\xbf\x03\n\rHorizonData3D\x12\'\n\x04mode\x18\x01 \x01(\x0e\x32\x13.HorizonData3D.MODE:\x04\x46ULL\x12\x15\n\rfirstRowIndex\x18\x02 \x01(\x05\x12\x14\n\x0cnumberOfRows\x18\x03 \x01(\x05\x12\x18\n\x10\x66irstColumnIndex\x18\x04 \x01(\x05\x12\x17\n\x0fnumberOfColumns\x18\x05 \x01(\x05\x12\"\n\x05lines\x18\x06 \x03(\x0b\x32\x13.HorizonData3D.Line\x12\'\n\x07samples\x18\x07 \x01(\x0b\x32\x16.HorizonData3D.Samples\x1aV\n\x04Line\x12+\n\tdirection\x18\x01 \x02(\x0e\x32\x18.HorizonData3D.DIRECTION\x12\x11\n\tlineIndex\x18\x02 \x02(\x05\x12\x0e\n\x06values\x18\x03 \x03(\x02\x1a?\n\x07Samples\x12\x13\n\x0b\x63olumnIndex\x18\x01 \x03(\x05\x12\x10\n\x08rowIndex\x18\x02 \x03(\x05\x12\r\n\x05value\x18\x03 \x03(\x02\"\x1d\n\x04MODE\x12\x08\n\x04\x46ULL\x10\x01\x12\x0b\n\x07SAMPLES\x10\x02\" \n\tDIRECTION\x12\x07\n\x03ROW\x10\x01\x12\n\n\x06\x43OLUMN\x10\x02')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'protobuf_definitions.horizon.H3DProtoBuf_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  DESCRIPTOR._loaded_options = None
  _globals['_HORIZONDATA3D']._serialized_start=51
  _globals['_HORIZONDATA3D']._serialized_end=498
  _globals['_HORIZONDATA3D_LINE']._serialized_start=282
  _globals['_HORIZONDATA3D_LINE']._serialized_end=368
  _globals['_HORIZONDATA3D_SAMPLES']._serialized_start=370
  _globals['_HORIZONDATA3D_SAMPLES']._serialized_end=433
  _globals['_HORIZONDATA3D_MODE']._serialized_start=435
  _globals['_HORIZONDATA3D_MODE']._serialized_end=464
  _globals['_HORIZONDATA3D_DIRECTION']._serialized_start=466
  _globals['_HORIZONDATA3D_DIRECTION']._serialized_end=498
# @@protoc_insertion_point(module_scope)
