# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: protobuf-definitions/tabular/LGCProtoBuf.proto
# Protobuf Python Version: 6.33.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    33,
    0,
    '',
    'protobuf-definitions/tabular/LGCProtoBuf.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n.protobuf-definitions/tabular/LGCProtoBuf.proto\"\x83\x04\n\x0cLGCStructure\x12\x17\n\nstructName\x18\x01 \x01(\t:\x03NaN\x12*\n\x08\x65lements\x18\x03 \x03(\x0b\x32\x18.LGCStructure.LGCElement\x1a\xc0\x02\n\nLGCElement\x12\x1d\n\x0cunitTypeName\x18\x0b \x01(\t:\x07UNKNOWN\x12\x19\n\x08unitName\x18\x0c \x01(\t:\x07UNKNOWN\x12\x18\n\x0b\x65lementName\x18\x01 \x01(\t:\x03NaN\x12\x30\n\x08\x64\x61taType\x18\x02 \x01(\x0e\x32\x16.LGCStructure.DataType:\x06STRUCT\x12\x13\n\x0b\x64\x61ta_string\x18\x03 \x03(\t\x12\x10\n\x08\x64\x61ta_int\x18\x04 \x03(\x11\x12\x12\n\ndata_float\x18\x05 \x03(\x02\x12\x13\n\x0b\x64\x61ta_double\x18\x06 \x03(\x01\x12\x11\n\tdata_long\x18\x07 \x03(\x12\x12\"\n\x0b\x64\x61ta_struct\x18\x08 \x03(\x0b\x32\r.LGCStructure\x12\x12\n\ndata_short\x18\t \x03(\x11\x12\x11\n\tdata_byte\x18\n \x01(\x0c\"k\n\x08\x44\x61taType\x12\n\n\x06STRUCT\x10\x00\x12\x07\n\x03INT\x10\x01\x12\t\n\x05\x46LOAT\x10\x02\x12\n\n\x06\x44OUBLE\x10\x03\x12\x08\n\x04LONG\x10\x04\x12\n\n\x06STRING\x10\x05\x12\t\n\x05SHORT\x10\x06\x12\x08\n\x04\x42YTE\x10\x07\x12\x08\n\x04\x43HAR\x10\x08')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'protobuf_definitions.tabular.LGCProtoBuf_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  DESCRIPTOR._loaded_options = None
  _globals['_LGCSTRUCTURE']._serialized_start=51
  _globals['_LGCSTRUCTURE']._serialized_end=566
  _globals['_LGCSTRUCTURE_LGCELEMENT']._serialized_start=137
  _globals['_LGCSTRUCTURE_LGCELEMENT']._serialized_end=457
  _globals['_LGCSTRUCTURE_DATATYPE']._serialized_start=459
  _globals['_LGCSTRUCTURE_DATATYPE']._serialized_end=566
# @@protoc_insertion_point(module_scope)
