# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: protobuf-definitions/seismic/SeismicDataFloatBuf.proto
# Protobuf Python Version: 6.33.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    33,
    0,
    '',
    'protobuf-definitions/seismic/SeismicDataFloatBuf.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n6protobuf-definitions/seismic/SeismicDataFloatBuf.proto\x12\x08\x62ulkdata\"\xd5\x01\n\nArray3FBuf\x12+\n\x06length\x18\x01 \x01(\x0b\x32\x1b.bulkdata.Array3FBuf.Index3\x12\x10\n\x04\x64\x61ta\x18\x02 \x03(\x02\x42\x02\x10\x01\x12+\n\x06header\x18\x03 \x01(\x0b\x32\x1b.bulkdata.Array3FBuf.Header\x1a)\n\x06Index3\x12\t\n\x01i\x18\x01 \x02(\x05\x12\t\n\x01j\x18\x02 \x02(\x05\x12\t\n\x01k\x18\x03 \x02(\x05\x1a\x30\n\x06Header\x12\t\n\x01x\x18\x01 \x02(\x01\x12\t\n\x01y\x18\x02 \x02(\x01\x12\x10\n\x08scalarXY\x18\x03 \x02(\x05\"7\n\x0e\x41rray3FBufList\x12%\n\x07\x61rray3F\x18\x01 \x03(\x0b\x32\x14.bulkdata.Array3FBuf\"\xdd\x01\n\nArray2FBuf\x12+\n\x06length\x18\x01 \x01(\x0b\x32\x1b.bulkdata.Array2FBuf.Index2\x12\x10\n\x04\x64\x61ta\x18\x02 \x03(\x02\x42\x02\x10\x01\x12+\n\x06header\x18\x03 \x01(\x0b\x32\x1b.bulkdata.Array2FBuf.Header\x1a\x1e\n\x06Index2\x12\t\n\x01i\x18\x01 \x02(\x05\x12\t\n\x01k\x18\x02 \x02(\x05\x1a\x43\n\x06Header\x12\t\n\x01x\x18\x01 \x02(\x01\x12\t\n\x01y\x18\x02 \x02(\x01\x12\x11\n\tshotpoint\x18\x03 \x02(\x02\x12\x10\n\x08scalarXY\x18\x04 \x02(\x05\"7\n\x0e\x41rray2FBufList\x12%\n\x07\x61rray2F\x18\x01 \x03(\x0b\x32\x14.bulkdata.Array2FBufB\x12\n\x10\x63om.lgc.bulkdata')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'protobuf_definitions.seismic.SeismicDataFloatBuf_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\020com.lgc.bulkdata'
  _globals['_ARRAY3FBUF'].fields_by_name['data']._loaded_options = None
  _globals['_ARRAY3FBUF'].fields_by_name['data']._serialized_options = b'\020\001'
  _globals['_ARRAY2FBUF'].fields_by_name['data']._loaded_options = None
  _globals['_ARRAY2FBUF'].fields_by_name['data']._serialized_options = b'\020\001'
  _globals['_ARRAY3FBUF']._serialized_start=69
  _globals['_ARRAY3FBUF']._serialized_end=282
  _globals['_ARRAY3FBUF_INDEX3']._serialized_start=191
  _globals['_ARRAY3FBUF_INDEX3']._serialized_end=232
  _globals['_ARRAY3FBUF_HEADER']._serialized_start=234
  _globals['_ARRAY3FBUF_HEADER']._serialized_end=282
  _globals['_ARRAY3FBUFLIST']._serialized_start=284
  _globals['_ARRAY3FBUFLIST']._serialized_end=339
  _globals['_ARRAY2FBUF']._serialized_start=342
  _globals['_ARRAY2FBUF']._serialized_end=563
  _globals['_ARRAY2FBUF_INDEX2']._serialized_start=464
  _globals['_ARRAY2FBUF_INDEX2']._serialized_end=494
  _globals['_ARRAY2FBUF_HEADER']._serialized_start=496
  _globals['_ARRAY2FBUF_HEADER']._serialized_end=563
  _globals['_ARRAY2FBUFLIST']._serialized_start=565
  _globals['_ARRAY2FBUFLIST']._serialized_end=620
# @@protoc_insertion_point(module_scope)
