# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: protobuf-definitions/seismic/SeismicDataHeaderBuf.proto
# Protobuf Python Version: 6.33.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    33,
    0,
    '',
    'protobuf-definitions/seismic/SeismicDataHeaderBuf.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n7protobuf-definitions/seismic/SeismicDataHeaderBuf.proto\x12\x08\x62ulkdata\"\x93\x03\n\x11SeismicDataHeader\x12+\n\x08\x64\x61taType\x18\x01 \x02(\x0e\x32\x12.bulkdata.DataType:\x05\x46LOAT\x12\x31\n\x05\x66irst\x18\x03 \x02(\x0b\x32\".bulkdata.SeismicDataHeader.Index3\x12\x32\n\x06length\x18\x04 \x02(\x0b\x32\".bulkdata.SeismicDataHeader.Index3\x12\x35\n\tincrement\x18\x05 \x02(\x0b\x32\".bulkdata.SeismicDataHeader.Index3\x12<\n\x10transposeMapping\x18\x06 \x02(\x0b\x32\".bulkdata.SeismicDataHeader.Index3\x12$\n\x04mode\x18\x07 \x02(\x0e\x32\x0e.bulkdata.Mode:\x06XSLICE\x12$\n\rnavigationCRS\x18\x08 \x01(\x0b\x32\r.bulkdata.CRS\x1a)\n\x06Index3\x12\t\n\x01i\x18\x01 \x02(\x05\x12\t\n\x01j\x18\x02 \x02(\x05\x12\t\n\x01k\x18\x03 \x01(\x05\"\xd2\x02\n\x13SeismicDataHeader2D\x12+\n\x08\x64\x61taType\x18\x01 \x02(\x0e\x32\x12.bulkdata.DataType:\x05\x46LOAT\x12\x33\n\x05\x66irst\x18\x02 \x02(\x0b\x32$.bulkdata.SeismicDataHeader2D.Index2\x12\x34\n\x06length\x18\x03 \x02(\x0b\x32$.bulkdata.SeismicDataHeader2D.Index2\x12\x37\n\tincrement\x18\x04 \x02(\x0b\x32$.bulkdata.SeismicDataHeader2D.Index2\x12$\n\x04mode\x18\x05 \x02(\x0e\x32\x0e.bulkdata.Mode:\x06XSLICE\x12$\n\rnavigationCRS\x18\x06 \x01(\x0b\x32\r.bulkdata.CRS\x1a\x1e\n\x06Index2\x12\t\n\x01i\x18\x01 \x02(\x05\x12\t\n\x01k\x18\x02 \x01(\x05\".\n\x03\x43RS\x12\x0c\n\x04name\x18\x01 \x02(\t\x12\x19\n\x0bisProjected\x18\x02 \x02(\x08:\x04true*3\n\x08\x44\x61taType\x12\t\n\x05\x46LOAT\x10\x01\x12\t\n\x05SHORT\x10\x02\x12\x07\n\x03INT\x10\x03\x12\x08\n\x04\x42YTE\x10\x04*n\n\x04Mode\x12\n\n\x06XSLICE\x10\x01\x12\n\n\x06YSLICE\x10\x02\x12\t\n\x05TRACE\x10\x03\x12\x06\n\x02XY\x10\x04\x12\x06\n\x02YX\x10\x05\x12\r\n\tLIVETRACE\x10\x06\x12\x0b\n\x07XSLICES\x10\x07\x12\x0b\n\x07YSLICES\x10\x08\x12\n\n\x06ZSLICE\x10\tB\x12\n\x10\x63om.lgc.bulkdata')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'protobuf_definitions.seismic.SeismicDataHeaderBuf_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\020com.lgc.bulkdata'
  _globals['_DATATYPE']._serialized_start=864
  _globals['_DATATYPE']._serialized_end=915
  _globals['_MODE']._serialized_start=917
  _globals['_MODE']._serialized_end=1027
  _globals['_SEISMICDATAHEADER']._serialized_start=70
  _globals['_SEISMICDATAHEADER']._serialized_end=473
  _globals['_SEISMICDATAHEADER_INDEX3']._serialized_start=432
  _globals['_SEISMICDATAHEADER_INDEX3']._serialized_end=473
  _globals['_SEISMICDATAHEADER2D']._serialized_start=476
  _globals['_SEISMICDATAHEADER2D']._serialized_end=814
  _globals['_SEISMICDATAHEADER2D_INDEX2']._serialized_start=784
  _globals['_SEISMICDATAHEADER2D_INDEX2']._serialized_end=814
  _globals['_CRS']._serialized_start=816
  _globals['_CRS']._serialized_end=862
# @@protoc_insertion_point(module_scope)
