# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: protobuf-definitions/logcurve/LogCurveBuf.proto
# Protobuf Python Version: 6.33.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    33,
    0,
    '',
    'protobuf-definitions/logcurve/LogCurveBuf.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n/protobuf-definitions/logcurve/LogCurveBuf.proto\x12\x08\x62ulkdata\"\xe9\x07\n\tLogCurves\x12\x38\n\ncurve_type\x18\x01 \x01(\x0e\x32\x1d.bulkdata.LogCurves.IndexType:\x05\x44\x45PTH\x12(\n\x05index\x18\x02 \x01(\x0b\x32\x19.bulkdata.LogCurves.Index\x12.\n\x06values\x18\x03 \x03(\x0b\x32\x1e.bulkdata.LogCurves.CurveValue\x1a\xfc\x03\n\nCurveValue\x12:\n\x0bsample_type\x18\x01 \x02(\x0e\x32\x1e.bulkdata.LogCurves.SampleType:\x05VALUE\x12\x37\n\tdata_type\x18\x02 \x02(\x0e\x32\x1c.bulkdata.LogCurves.DataType:\x06\x44OUBLE\x12\x11\n\tunit_type\x18\x03 \x01(\t\x12\x0c\n\x04unit\x18\x04 \x01(\t\x12\x18\n\rfixed_columns\x18\x05 \x01(\r:\x01\x31\x12\x15\n\nfixed_rows\x18\x06 \x01(\r:\x01\x31\x12\x15\n\rvariable_size\x18\x07 \x03(\x11\x12\x13\n\x0b\x64\x61ta_string\x18\x08 \x03(\t\x12\x14\n\x08\x64\x61ta_int\x18\t \x03(\x11\x42\x02\x10\x01\x12\x16\n\ndata_float\x18\n \x03(\x02\x42\x02\x10\x01\x12\x17\n\x0b\x64\x61ta_double\x18\x0b \x03(\x01\x42\x02\x10\x01\x12\x15\n\tdata_long\x18\x0c \x03(\x12\x42\x02\x10\x01\x12\x0c\n\x04name\x18\r \x01(\t\x12\x33\n\x10second_dimension\x18\x0e \x01(\x0b\x32\x19.bulkdata.LogCurves.Index\x12\x32\n\x0fthird_dimension\x18\x0f \x01(\x0b\x32\x19.bulkdata.LogCurves.Index\x12\x12\n\nnull_value\x18\x10 \x01(\x01\x12\x12\n\nnative_uid\x18\x11 \x01(\t\x1a|\n\x05Index\x12\x11\n\tincrement\x18\x01 \x02(\x01\x12\x13\n\x0bstart_index\x18\x02 \x01(\x01\x12\x17\n\x0fnumber_of_index\x18\x03 \x01(\r\x12\x11\n\tunit_type\x18\x04 \x01(\t\x12\x0c\n\x04unit\x18\x05 \x01(\t\x12\x11\n\x05index\x18\x06 \x03(\x01\x42\x02\x10\x01\" \n\tIndexType\x12\t\n\x05\x44\x45PTH\x10\x01\x12\x08\n\x04TIME\x10\x02\"@\n\x08\x44\x61taType\x12\n\n\x06\x44OUBLE\x10\x01\x12\t\n\x05\x46LOAT\x10\x02\x12\x07\n\x03INT\x10\x03\x12\x08\n\x04LONG\x10\x04\x12\n\n\x06STRING\x10\x05\"g\n\nSampleType\x12\t\n\x05VALUE\x10\x01\x12\x0f\n\x0b\x46IXEDLIST1D\x10\x02\x12\x0f\n\x0b\x46IXEDLIST2D\x10\x03\x12\x10\n\x0cVARIABLELIST\x10\x04\x12\x1a\n\x16\x46IXEDROWSVARCOLSLIST2D\x10\x05\x42\x12\n\x10\x63om.lgc.bulkdata')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'protobuf_definitions.logcurve.LogCurveBuf_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\020com.lgc.bulkdata'
  _globals['_LOGCURVES_CURVEVALUE'].fields_by_name['data_int']._loaded_options = None
  _globals['_LOGCURVES_CURVEVALUE'].fields_by_name['data_int']._serialized_options = b'\020\001'
  _globals['_LOGCURVES_CURVEVALUE'].fields_by_name['data_float']._loaded_options = None
  _globals['_LOGCURVES_CURVEVALUE'].fields_by_name['data_float']._serialized_options = b'\020\001'
  _globals['_LOGCURVES_CURVEVALUE'].fields_by_name['data_double']._loaded_options = None
  _globals['_LOGCURVES_CURVEVALUE'].fields_by_name['data_double']._serialized_options = b'\020\001'
  _globals['_LOGCURVES_CURVEVALUE'].fields_by_name['data_long']._loaded_options = None
  _globals['_LOGCURVES_CURVEVALUE'].fields_by_name['data_long']._serialized_options = b'\020\001'
  _globals['_LOGCURVES_INDEX'].fields_by_name['index']._loaded_options = None
  _globals['_LOGCURVES_INDEX'].fields_by_name['index']._serialized_options = b'\020\001'
  _globals['_LOGCURVES']._serialized_start=62
  _globals['_LOGCURVES']._serialized_end=1063
  _globals['_LOGCURVES_CURVEVALUE']._serialized_start=224
  _globals['_LOGCURVES_CURVEVALUE']._serialized_end=732
  _globals['_LOGCURVES_INDEX']._serialized_start=734
  _globals['_LOGCURVES_INDEX']._serialized_end=858
  _globals['_LOGCURVES_INDEXTYPE']._serialized_start=860
  _globals['_LOGCURVES_INDEXTYPE']._serialized_end=892
  _globals['_LOGCURVES_DATATYPE']._serialized_start=894
  _globals['_LOGCURVES_DATATYPE']._serialized_end=958
  _globals['_LOGCURVES_SAMPLETYPE']._serialized_start=960
  _globals['_LOGCURVES_SAMPLETYPE']._serialized_end=1063
# @@protoc_insertion_point(module_scope)
