"""
DSIS SDK Native Models

Auto-generated model imports for all native entities.
Generated on: 2025-10-09T21:15:05.117286
"""

from .base import BaseModel

# Generated model imports
from .activity import Activity
from .analysis_log_use import AnalysisLogUse
from .analysis_parm_use import AnalysisParmUse
from .app_cord_trfm import AppCordTrfm
from .application_data import ApplicationData
from .application_text_data import ApplicationTextData
from .baseline import Baseline
from .baseline_all import BaselineAll
from .basin import Basin
from .basin_boundary import BasinBoundary
from .binset_grid_2d_shpt_trace import BinsetGrid2DShptTrace
from .binset_grid_3d_grid import BinsetGrid3DGrid
from .bit_record import BitRecord
from .blow_out import BlowOut
from .body_fault_contact import BodyFaultContact
from .body_fault_contact_all import BodyFaultContactAll
from .body_surface_contact import BodySurfaceContact
from .body_surface_contact_all import BodySurfaceContactAll
from .calc_lith import CalcLith
from .calc_lith_head import CalcLithHead
from .carter_bh_location import CarterBHLocation
from .carter_surface_location import CarterSurfaceLocation
from .carto_ref_sys import CartoRefSys
from .casing import Casing
from .clip_polygon import ClipPolygon
from .clip_polygon_all import ClipPolygonAll
from .cntr_line import CntrLine
from .cntr_line_all import CntrLineAll
from .cntr_parm import CntrParm
from .cntr_parm_all import CntrParmAll
from .cntr_set import CntrSet
from .cntr_set_all import CntrSetAll
from .congress_bh_location import CongressBHLocation
from .congress_surface_location import CongressSurfaceLocation
from .control_point import ControlPoint
from .coordinate_sys import CoordinateSys
from .coordinate_trfm import CoordinateTrfm
from .cord_trfm_mth import CordTrfmMth
from .cord_trfm_par import CordTrfmPar
from .cord_trfm_val import CordTrfmVal
from .core_property_alys import CorePropertyAlys
from .core_property_alys_detail import CorePropertyAlysDetail
from .cost import Cost
from .country_basin import CountryBasin
from .cross_section import CrossSection
from .cross_section_all import CrossSectionAll
from .crv_backup import CrvBackup
from .crv_summation import CrvSummation
from .crv_summation_member import CrvSummationMember
from .crv_template import CrvTemplate
from .curve_hist_rmk import CurveHistRmk
from .curve_mnemonic_group import CurveMnemonicGroup
from .curve_mnemonic_group_member import CurveMnemonicGroupMember
from .ds_session import DSSession
from .ds_session_editor import DSSessionEditor
from .ds_session_folder import DSSessionFolder
from .ds_session_project import DSSessionProject
from .ds_template import DSTemplate
from .daily_activity import DailyActivity
from .daily_summary import DailySummary
from .data_dict_value import DataDictValue
from .data_dictionary import DataDictionary
from .data_src import DataSrc
from .data_src_user import DataSrcUser
from .dipmeter import Dipmeter
from .dir_survey import DirSurvey
from .dls_bh_location import DlsBHLocation
from .dls_surface_location import DlsSurfaceLocation
from .drilg_log import DrilgLog
from .drill_pump import DrillPump
from .drillers_estimator_pt import DrillersEstimatorPt
from .drillers_estimator_pt_all import DrillersEstimatorPtAll
from .drilling_obj import DrillingObj
from .dst_job_hdr import DstJobHdr
from .dst_rft_cush import DstRftCush
from .dst_rft_fluid import DstRftFluid
from .dst_rft_gen import DstRftGen
from .dst_rft_mat_surf import DstRftMatSurf
from .dst_rft_press import DstRftPress
from .dst_rft_summary import DstRftSummary
from .earth_model_study import EarthModelStudy
from .earth_model_study_all import EarthModelStudyAll
from .eco_phase import EcoPhase
from .econ_output_config import EconOutputConfig
from .econ_stream_type import EconStreamType
from .elev_info import ElevInfo
from .ellipsoid import Ellipsoid
from .em_body_surface_contact import EmBodySurfaceContact
from .em_body_surface_contact_all import EmBodySurfaceContactAll
from .em_cleaning_radius import EmCleaningRadius
from .em_cleaning_radius_all import EmCleaningRadiusAll
from .em_compartment import EmCompartment
from .em_compartment_all import EmCompartmentAll
from .em_compartment_model import EmCompartmentModel
from .em_compartment_model_all import EmCompartmentModelAll
from .em_compartment_patch import EmCompartmentPatch
from .em_compartment_patch_all import EmCompartmentPatchAll
from .em_contour import EmContour
from .em_contour_all import EmContourAll
from .em_cross_section import EmCrossSection
from .em_cross_section_all import EmCrossSectionAll
from .em_cross_section_surface import EmCrossSectionSurface
from .em_cross_section_surface_all import EmCrossSectionSurfaceAll
from .em_fault import EmFault
from .em_fault_all import EmFaultAll
from .em_fault_fault_contact import EmFaultFaultContact
from .em_fault_fault_contact_all import EmFaultFaultContactAll
from .em_fault_surface_contact import EmFaultSurfaceContact
from .em_fault_surface_contact_all import EmFaultSurfaceContactAll
from .em_fluid_contact import EmFluidContact
from .em_fluid_contact_all import EmFluidContactAll
from .em_fluid_contact_prospect import EmFluidContactProspect
from .em_fluid_contact_prospect_all import EmFluidContactProspectAll
from .em_horizon import EmHorizon
from .em_horizon_all import EmHorizonAll
from .em_isochore_constraint import EmIsochoreConstraint
from .em_isochore_constraint_all import EmIsochoreConstraintAll
from .em_kriging import EmKriging
from .em_kriging_all import EmKrigingAll
from .em_layer_definition import EmLayerDefinition
from .em_layer_definition_all import EmLayerDefinitionAll
from .em_missing_top import EmMissingTop
from .em_missing_top_all import EmMissingTopAll
from .em_object_input import EmObjectInput
from .em_object_input_all import EmObjectInputAll
from .em_property_map import EmPropertyMap
from .em_property_map_all import EmPropertyMapAll
from .em_prospect import EmProspect
from .em_prospect_all import EmProspectAll
from .em_prospect_term_fault import EmProspectTermFault
from .em_prospect_term_fault_all import EmProspectTermFaultAll
from .em_pty_map_discontinuity import EmPtyMapDiscontinuity
from .em_pty_map_discontinuity_all import EmPtyMapDiscontinuityAll
from .em_pty_map_linr_bdry_func import EmPtyMapLinrBdryFunc
from .em_pty_map_linr_bdry_func_all import EmPtyMapLinrBdryFuncAll
from .em_restored_top import EmRestoredTop
from .em_restored_top_all import EmRestoredTopAll
from .em_structural_body import EmStructuralBody
from .em_structural_body_all import EmStructuralBodyAll
from .em_structural_model import EmStructuralModel
from .em_structural_model_all import EmStructuralModelAll
from .em_surface_surface_contact import EmSurfaceSurfaceContact
from .em_surface_surface_contact_all import EmSurfaceSurfaceContactAll
from .em_vertical_cpg import EmVerticalCpg
from .em_vertical_cpg_all import EmVerticalCpgAll
from .em_vertical_cpg_reservoir import EmVerticalCpgReservoir
from .em_vertical_cpg_reservoir_all import EmVerticalCpgReservoirAll
from .exploration_play import ExplorationPlay
from .ext_storage import ExtStorage
from .external_data_object import ExternalDataObject
from .fault import Fault
from .fault_center_line import FaultCenterLine
from .fault_center_line_all import FaultCenterLineAll
from .fault_center_line_set import FaultCenterLineSet
from .fault_center_line_set_all import FaultCenterLineSetAll
from .fault_cut import FaultCut
from .fault_cut_all import FaultCutAll
from .fault_display import FaultDisplay
from .fault_fault_contact import FaultFaultContact
from .fault_fault_contact_all import FaultFaultContactAll
from .fault_heave import FaultHeave
from .fault_list import FaultList
from .fault_list_member import FaultListMember
from .fault_network import FaultNetwork
from .fault_network_all import FaultNetworkAll
from .fault_network_fault import FaultNetworkFault
from .fault_network_fault_all import FaultNetworkFaultAll
from .fault_plane import FaultPlane
from .fault_plane_remark import FaultPlaneRemark
from .fault_plane_trimesh import FaultPlaneTrimesh
from .fault_point_set import FaultPointSet
from .fault_point_set_all import FaultPointSetAll
from .fault_polygon import FaultPolygon
from .fault_polygon_all import FaultPolygonAll
from .fault_polygon_set import FaultPolygonSet
from .fault_polygon_set_all import FaultPolygonSetAll
from .fault_profile import FaultProfile
from .fault_profile_all import FaultProfileAll
from .fault_segment import FaultSegment
from .fault_surf import FaultSurf
from .fault_surf_all import FaultSurfAll
from .fault_surface_contact import FaultSurfaceContact
from .fault_surface_contact_all import FaultSurfaceContactAll
from .fault_trimesh import FaultTrimesh
from .fgrid import Fgrid
from .fgrid_all import FgridAll
from .field_boundary import FieldBoundary
from .field_list import FieldList
from .field_list_member import FieldListMember
from .field_pros import FieldPros
from .field_pros_int import FieldProsInt
from .field_prospect_interest_scale import FieldProspectInterestScale
from .fill_template import FillTemplate
from .fps_bh_location import FpsBHLocation
from .fps_surface_location import FpsSurfaceLocation
from .frac_net_prop_set_member import FracNetPropSetMember
from .frac_net_prop_set_member_all import FracNetPropSetMemberAll
from .frac_net_property import FracNetProperty
from .frac_net_property_all import FracNetPropertyAll
from .frac_net_property_set import FracNetPropertySet
from .frac_net_property_set_all import FracNetPropertySetAll
from .frac_treatment_formation import FracTreatmentFormation
from .frac_well_property import FracWellProperty
from .fracture import Fracture
from .fracture_all import FractureAll
from .fracture_job_frac_well import FractureJobFracWell
from .fracture_network import FractureNetwork
from .fracture_network_all import FractureNetworkAll
from .fracture_network_slice import FractureNetworkSlice
from .fracture_network_slice_all import FractureNetworkSliceAll
from .fracture_network_slice_v2 import FractureNetworkSliceV2
from .fracture_network_slice_v2_all import FractureNetworkSliceV2All
from .fracture_pick import FracturePick
from .fracture_pick_all import FracturePickAll
from .fracture_pick_v import FracturePickV
from .fracture_property import FractureProperty
from .fracture_property_all import FracturePropertyAll
from .fracture_surface_geometry import FractureSurfaceGeometry
from .fracture_surface_geometry_all import FractureSurfaceGeometryAll
from .fracture_surface_property import FractureSurfaceProperty
from .fracture_surface_property_all import FractureSurfacePropertyAll
from .fracture_surface_volume import FractureSurfaceVolume
from .fracture_surface_volume_all import FractureSurfaceVolumeAll
from .fracture_trace import FractureTrace
from .fracture_trace_all import FractureTraceAll
from .function_attribute import FunctionAttribute
from .function_set_attribute import FunctionSetAttribute
from .geo_area import GeoArea
from .geo_shape_attribute import GeoShapeAttribute
from .geo_shape_set import GeoShapeSet
from .geo_shape_set_attribute import GeoShapeSetAttribute
from .geodetic_bh_location import GeodeticBHLocation
from .geodetic_datum import GeodeticDatum
from .geodetic_surface_location import GeodeticSurfaceLocation
from .geological_estimator_pt import GeologicalEstimatorPt
from .geological_estimator_pt_all import GeologicalEstimatorPtAll
from .geop_acq_area import GeopAcqArea
from .georeferenced_image_catalog import GeoreferencedImageCatalog
from .ggx_crv_cmd import GgxCrvCmd
from .ggx_crv_set import GgxCrvSet
from .ggx_crv_set_cmd import GgxCrvSetCmd
from .ggx_key_fld_look_up import GgxKeyFldLookUp
from .ggx_key_tbl_look_up import GgxKeyTblLookUp
from .ggx_schema_ver import GgxSchemaVer
from .ggx_surf_guiding_pts import GgxSurfGuidingPts
from .ggx_well_metadata import GgxWellMetadata
from .grid import Grid
from .grid3_d import Grid3D
from .grid_3d_all import Grid3DAll
from .grid_3d_interval import Grid3DInterval
from .grid_3d_interval_all import Grid3DIntervalAll
from .grid_3d_layering import Grid3DLayering
from .grid_3d_layering_all import Grid3DLayeringAll
from .grid_all import GridAll
from .grid_list import GridList
from .grid_list_member import GridListMember
from .grid_region import GridRegion
from .grid_set import GridSet
from .grid_set_member import GridSetMember
from .grid_set_region import GridSetRegion
from .gridded_3d_volume import Gridded3DVolume
from .gridded_3d_volume_all import Gridded3DVolumeAll
from .gx_fault_field_pt import GxFaultFieldPt
from .gx_strat_field_section import GxStratFieldSection
from .gx_well_log_ann import GxWellLogAnn
from .histogram import Histogram
from .horizon_2d_attribute import Horizon2DAttribute
from .horizon_attribute_catalog import HorizonAttributeCatalog
from .horizon_attribute_hdr import HorizonAttributeHdr
from .horizon_attribute_remark import HorizonAttributeRemark
from .horizon_body_cleaning_area import HorizonBodyCleaningArea
from .horizon_body_cleaning_area_all import HorizonBodyCleaningAreaAll
from .horizon_catalog import HorizonCatalog
from .horizon_change_log import HorizonChangeLog
from .horizon_cleaning_area import HorizonCleaningArea
from .horizon_cleaning_area_all import HorizonCleaningAreaAll
from .horizon_data import HorizonData
from .horizon_data_remark import HorizonDataRemark
from .horizon_list_header import HorizonListHeader
from .horizon_list_member import HorizonListMember
from .horizon_parms import HorizonParms
from .horizon_patch import HorizonPatch
from .horizon_patch_all import HorizonPatchAll
from .horizon_polygon_set_usage import HorizonPolygonSetUsage
from .horizon_z_layer_attr import HorizonZLayerAttr
from .horizon_z_layer_data import HorizonZLayerData
from .hwc_interp_control_pt import HwcInterpControlPt
from .hwc_interp_predicted_curve import HwcInterpPredictedCurve
from .hwc_interp_type_log_setting import HwcInterpTypeLogSetting
from .hwc_interpretation import HwcInterpretation
from .hwc_interpretation_pref import HwcInterpretationPref
from .hybrid_3d_volume import Hybrid3DVolume
from .hybrid_3d_volume_attribute import Hybrid3DVolumeAttribute
from .i3_dv import I3DV
from .i3_dv_all import I3DVAll
from .i3_dv_data import I3DVData
from .i3_dv_data_all import I3DVDataAll
from .i_geometry import IGeometry
from .i_geometry_all import IGeometryAll
from .i_note_classification import INoteClassification
from .i_note_document import INoteDocument
from .i_note_document_link import INoteDocumentLink
from .i_note_image import INoteImage
from .i_note_image_symbol import INoteImageSymbol
from .i_note_list_hdr import INoteListHdr
from .i_note_list_member import INoteListMember
from .i_note_query import INoteQuery
from .i_note_summary import INoteSummary
from .i_note_text_block import INoteTextBlock
from .ir_points import IRPoints
from .ir_points_all import IRPointsAll
from .i_set_category import ISetCategory
from .i_set_data_object import ISetDataObject
from .i_set_dynamic_query import ISetDynamicQuery
from .i_set_folder import ISetFolder
from .i_set_property import ISetProperty
from .i_set_template import ISetTemplate
from .i_set_template_folder import ISetTemplateFolder
from .i_set_template_obj_type import ISetTemplateObjType
from .inter_well_attribute import InterWellAttribute
from .interest import Interest
from .interest_scale import InterestScale
from .interp_list_member import InterpListMember
from .interp_priority_list import InterpPriorityList
from .interp_prj_3d_seismic import InterpPrj3DSeismic
from .interp_prj_aoi import InterpPrjAOI
from .interp_process_input import InterpProcessInput
from .interp_process_output import InterpProcessOutput
from .interp_process_parm import InterpProcessParm
from .interpretation_note import InterpretationNote
from .interpretation_process import InterpretationProcess
from .interpretation_project import InterpretationProject
from .interpretation_set import InterpretationSet
from .interpretation_study import InterpretationStudy
from .intrp_drilg_show import IntrpDrilgShow
from .ka_links import KaLinks
from .ka_results import KaResults
from .ka_symbols import KaSymbols
from .key_well import KeyWell
from .lease import Lease
from .lease_comm import LeaseComm
from .lease_field_pros import LeaseFieldPros
from .lease_interest_scale import LeaseInterestScale
from .lease_list import LeaseList
from .lease_list_member import LeaseListMember
from .lease_narrative import LeaseNarrative
from .lease_tract import LeaseTract
from .lessee import Lessee
from .lessor import Lessor
from .license_rnd import LicenseRnd
from .line_segment import LineSegment
from .line_segment_all import LineSegmentAll
from .liner import Liner
from .lithotype_facies import LithotypeFacies
from .loc_remark import LocRemark
from .locked_well_attribute import LockedWellAttribute
from .locked_well_category import LockedWellCategory
from .locked_well_locn_attribute import LockedWellLocnAttribute
from .locked_well_locn_category import LockedWellLocnCategory
from .log_crv_list import LogCrvList
from .log_crv_list_member import LogCrvListMember
from .log_curve import LogCurve
from .log_curve_qualifier import LogCurveQualifier
from .log_curve_struct import LogCurveStruct
from .log_curve_structured import LogCurveStructured
from .log_image_alias import LogImageAlias
from .log_image_alias_group import LogImageAliasGroup
from .log_image_reg_log_section import LogImageRegLogSection
from .log_image_unreg_image import LogImageUnregImage
from .log_sample_block_info import LogSampleBlockInfo
from .log_sample_framework import LogSampleFramework
from .log_trace_analysis import LogTraceAnalysis
from .logging_job import LoggingJob
from .logging_mud_test import LoggingMudTest
from .logging_sensor_parm import LoggingSensorParm
from .logging_tool import LoggingTool
from .logging_tool_calib import LoggingToolCalib
from .logging_tool_config import LoggingToolConfig
from .logging_tool_equipment import LoggingToolEquipment
from .logging_tool_parm import LoggingToolParm
from .logging_tool_pass import LoggingToolPass
from .logging_tool_service import LoggingToolService
from .logging_tool_string_descent import LoggingToolStringDescent
from .lost_circ import LostCirc
from .mwd_run import MWDRun
from .map_data_hist import MapDataHist
from .mapping_poly_set import MappingPolySet
from .mapping_poly_set_all import MappingPolySetAll
from .mapping_polygon import MappingPolygon
from .mapping_polygon_all import MappingPolygonAll
from .mdm_mime_application import MdmMimeApplication
from .mdm_mime_type import MdmMimeType
from .meas_system_member import MeasSystemMember
from .meas_unit_type_member import MeasUnitTypeMember
from .measurement_system import MeasurementSystem
from .measurement_unit import MeasurementUnit
from .measurement_unit_type import MeasurementUnitType
from .microseismic_event_property import MicroseismicEventProperty
from .microseismic_job import MicroseismicJob
from .microseismic_monitor_well import MicroseismicMonitorWell
from .microseismic_stage import MicroseismicStage
from .microseismic_vol_alys_parm import MicroseismicVolAlysParm
from .microseismic_vol_alys_stage import MicroseismicVolAlysStage
from .microseismic_volumetric_alys import MicroseismicVolumetricAlys
from .mistie_function_hdr import MistieFunctionHdr
from .mistie_function_member import MistieFunctionMember
from .mud_report import MudReport
from .mudlog_desc import MudlogDesc
from .mudlog_hdr import MudlogHdr
from .narrative_surface_location import NarrativeSurfaceLocation
from .natural_fracture_pick import NaturalFracturePick
from .nominal_seismic_geometry import NominalSeismicGeometry
from .north_sea_bh_location import NorthSeaBHLocation
from .north_sea_surface_location import NorthSeaSurfaceLocation
from .northeast_bh_location import NortheastBHLocation
from .northeast_surface_location import NortheastSurfaceLocation
from .nts_bh_location import NtsBHLocation
from .nts_surface_location import NtsSurfaceLocation
from .ocs_bh_location import OcsBHLocation
from .ocs_surface_location import OcsSurfaceLocation
from .ohio_bh_location import OhioBHLocation
from .ohio_surface_location import OhioSurfaceLocation
from .ow_data_lock_value import OwDataLockValue
from .ow_db_data_file_dir import OwDbDataFileDir
from .ow_query import OwQuery
from .ow_query_def import OwQueryDef
from .ow_query_name import OwQueryName
from .ow_saved_query import OwSavedQuery
from .owsys_datum_shift_defaults import OwsysDatumShiftDefaults
from .owsys_interpretation_prj import OwsysInterpretationPrj
from .owsys_prj_user import OwsysPrjUser
from .owsys_project import OwsysProject
from .owsys_user import OwsysUser
from .packer import Packer
from .paleo import Paleo
from .paleo_sample_analysis import PaleoSampleAnalysis
from .paleo_sample_analysis_detail import PaleoSampleAnalysisDetail
from .pca_factor_data import PcaFactorData
from .pca_factor_data_all import PcaFactorDataAll
from .pca_input_data import PcaInputData
from .pca_input_data_all import PcaInputDataAll
from .pden_gas_anal import PdenGasAnal
from .pden_gas_anal_dtl import PdenGasAnalDtl
from .pden_hdr import PdenHdr
from .pden_oil_anal import PdenOilAnal
from .pden_oil_anal_dtl import PdenOilAnalDtl
from .pden_oil_visc import PdenOilVisc
from .pden_water_anal import PdenWaterAnal
from .pden_water_anal_dtl import PdenWaterAnalDtl
from .pdm_daily_injection import PdmDailyInjection
from .pdm_daily_prod import PdmDailyProd
from .pdm_econ_detail import PdmEconDetail
from .pdm_econ_monthly import PdmEconMonthly
from .pdm_econ_oneline import PdmEconOneline
from .pdm_facility_group import PdmFacilityGroup
from .pdm_group_alloc import PdmGroupAlloc
from .pdm_monthly_injection import PdmMonthlyInjection
from .pdm_monthly_prod import PdmMonthlyProd
from .pdm_prod_cums import PdmProdCums
from .petrophysical_parm_value import PetrophysicalParmValue
from .pick import Pick
from .plan_opt_parm import PlanOptParm
from .plan_opt_parm_all import PlanOptParmAll
from .plan_parameter import PlanParameter
from .plan_parameter_set import PlanParameterSet
from .platform_info import PlatformInfo
from .platform_slot import PlatformSlot
from .plugging import Plugging
from .point_set import PointSet
from .point_set_all import PointSetAll
from .point_set_composite import PointSetComposite
from .point_set_composite_all import PointSetCompositeAll
from .point_set_field import PointSetField
from .point_set_field_all import PointSetFieldAll
from .point_set_lithotype import PointSetLithotype
from .point_set_region import PointSetRegion
from .poly_parameter import PolyParameter
from .poly_parameter_all import PolyParameterAll
from .pool import Pool
from .pool_fluid_contact import PoolFluidContact
from .pool_vol_anal import PoolVolAnal
from .pool_volume import PoolVolume
from .pos_log import PosLog
from .pref_well_z_conversion import PrefWellZConversion
from .preferred_shift_set import PreferredShiftSet
from .preferred_synthetic import PreferredSynthetic
from .preferred_synthetic2_d import PreferredSynthetic2D
from .preferred_td_curve import PreferredTDCurve
from .prestack_horizon_data import PrestackHorizonData
from .prestack_horizon_hdr import PrestackHorizonHdr
from .prestack_hrzn_data_attribute import PrestackHrznDataAttribute
from .prestack_hrzn_data_remark import PrestackHrznDataRemark
from .prestack_hrzn_hdr_remark import PrestackHrznHdrRemark
from .prime_meridian import PrimeMeridian
from .principal_component_analysis import PrincipalComponentAnalysis
from .principal_component_analysis_all import PrincipalComponentAnalysisAll
from .process_data_type import ProcessDataType
from .prod_facility import ProdFacility
from .prod_interest import ProdInterest
from .proj_db_user import ProjDBUser
from .proj_remark import ProjRemark
from .proj_remark_type import ProjRemarkType
from .proj_user import ProjUser
from .project import Project
from .project_all import ProjectAll
from .project_extension import ProjectExtension
from .r_alias import RAlias
from .r_analysis_version import RAnalysisVersion
from .r_basin_type import RBasinType
from .r_binary_data_fmt import RBinaryDataFmt
from .r_borehole_type import RBoreholeType
from .r_comm_type import RCommType
from .r_company import RCompany
from .r_cord_sys_cstr import RCordSysCstr
from .r_cord_trfm import RCordTrfm
from .r_cord_trfm_par import RCordTrfmPar
from .r_core_analysis_type import RCoreAnalysisType
from .r_core_property import RCoreProperty
from .r_country import RCountry
from .r_county_name import RCountyName
from .r_currency import RCurrency
from .r_curve_type import RCurveType
from .r_data_acq_type import RDataAcqType
from .r_data_type import RDataType
from .r_digital_fmt import RDigitalFmt
from .r_disc_basis import RDiscBasis
from .r_distribution_type import RDistributionType
from .reom_down import REOMDown
from .r_element_orientation import RElementOrientation
from .r_em_property import REmProperty
from .r_fault_plane_rmk_type import RFaultPlaneRmkType
from .r_field_pros_stat import RFieldProsStat
from .r_fluid_anal_prop import RFluidAnalProp
from .r_fracture_network_property import RFractureNetworkProperty
from .r_fracture_property import RFractureProperty
from .r_function_attribute import RFunctionAttribute
from .r_function_property import RFunctionProperty
from .r_function_set_attribute import RFunctionSetAttribute
from .r_function_set_category import RFunctionSetCategory
from .r_gain_mode import RGainMode
from .r_geodetic_source import RGeodeticSource
from .r_geologic_feature import RGeologicFeature
from .r_geometry import RGeometry
from .r_geometry_all import RGeometryAll
from .r_horizon_attribute import RHorizonAttribute
from .r_horizon_attribute_rmk_type import RHorizonAttributeRmkType
from .r_horizon_class import RHorizonClass
from .r_horizon_data_rmk_type import RHorizonDataRmkType
from .r_horizon_name import RHorizonName
from .ri_note_data_obj_type import RINoteDataObjType
from .r_image_log_name import RImageLogName
from .r_image_type import RImageType
from .r_interest_type import RInterestType
from .r_interp_study_phase import RInterpStudyPhase
from .r_interp_study_type import RInterpStudyType
from .r_interpretation_status import RInterpretationStatus
from .r_interpretation_version import RInterpretationVersion
from .r_lease_event import RLeaseEvent
from .r_lock_data_category import RLockDataCategory
from .r_log_pass_type import RLogPassType
from .r_log_qualifier import RLogQualifier
from .r_logging_equip_type import RLoggingEquipType
from .r_logging_sensor_parm import RLoggingSensorParm
from .r_logging_service import RLoggingService
from .r_logging_tool_parm import RLoggingToolParm
from .r_map_proj import RMapProj
from .r_microseismic_alys_parm import RMicroseismicAlysParm
from .r_microseismic_event_pty import RMicroseismicEventPty
from .r_microseismic_srv_method import RMicroseismicSrvMethod
from .r_mineral_analysis_type import RMineralAnalysisType
from .r_narr_type import RNarrType
from .r_opt_parameter import ROptParameter
from .r_paleo_analysis_type import RPaleoAnalysisType
from .r_paleo_component import RPaleoComponent
from .r_parameter_atr import RParameterAtr
from .r_parm_relatn_type import RParmRelatnType
from .r_parm_type import RParmType
from .r_petro_act_type import RPetroActType
from .r_petro_parm_name import RPetroParmName
from .r_play_category import RPlayCategory
from .r_poly_parm import RPolyParm
from .r_position_type import RPositionType
from .r_prestack_hrzn_data_rmk_type import RPrestackHrznDataRmkType
from .r_prestack_hrzn_hdr_rmk_type import RPrestackHrznHdrRmkType
from .r_priority_list_category import RPriorityListCategory
from .r_process_io_type import RProcessIOType
from .r_process_parm import RProcessParm
from .r_process_type import RProcessType
from .r_prod_type import RProdType
from .r_property_set import RPropertySet
from .r_proposal_type import RProposalType
from .r_rec_pos import RRecPos
from .r_rec_type import RRecType
from .r_rush_cat import RRushCat
from .r_sample_format import RSampleFormat
from .r_seis_pick_onset import RSeisPickOnset
from .r_seis_prestack_datatype import RSeisPrestackDatatype
from .r_seis_prestack_rmk_type import RSeisPrestackRmkType
from .r_seis_z_type import RSeisZType
from .r_seismic_attribute import RSeismicAttribute
from .r_seismic_class import RSeismicClass
from .r_seismic_data_set_rmk_type import RSeismicDataSetRmkType
from .r_seismic_geometry import RSeismicGeometry
from .r_seismic_polarity import RSeismicPolarity
from .r_seismic_version import RSeismicVersion
from .r_seismic_vibrator_sweep import RSeismicVibratorSweep
from .r_shape_attribute import RShapeAttribute
from .r_shape_set_attribute import RShapeSetAttribute
from .r_shape_set_type import RShapeSetType
from .r_spread import RSpread
from .r_squeeze_test_type import RSqueezeTestType
from .r_state_name import RStateName
from .r_survey_environment import RSurveyEnvironment
from .r_syn_hrzn_data_rmk_type import RSynHrznDataRmkType
from .r_synthetic_2d_type import RSynthetic2DType
from .r_synthetic_type import RSyntheticType
from .r_target_type import RTargetType
from .r_test_per_type import RTestPerType
from .r_test_recov import RTestRecov
from .r_test_recov_meth import RTestRecovMeth
from .r_test_res import RTestRes
from .r_test_subtype import RTestSubtype
from .r_trajectory_shape import RTrajectoryShape
from .r_trfm_cstr import RTrfmCstr
from .r_velocity_model_attribute import RVelocityModelAttribute
from .r_volume_category import RVolumeCategory
from .r_volume_status import RVolumeStatus
from .r_vsp_data_set_type import RVspDataSetType
from .r_vsp_geometry_type import RVspGeometryType
from .rwp_interval_type import RWPIntervalType
from .r_wave_filt import RWaveFilt
from .r_wave_filt_algr import RWaveFiltAlgr
from .r_waveform import RWaveform
from .r_well_class import RWellClass
from .r_well_date_type import RWellDateType
from .r_well_name_type import RWellNameType
from .r_well_status import RWellStatus
from .r_well_test_purpose import RWellTestPurpose
from .r_well_test_type import RWellTestType
from .rz_layer_type import RZLayerType
from .regression_equation import RegressionEquation
from .regression_equation_all import RegressionEquationAll
from .regression_factor import RegressionFactor
from .regression_factor_all import RegressionFactorAll
from .regression_group import RegressionGroup
from .regression_group_all import RegressionGroupAll
from .regression_group_equation import RegressionGroupEquation
from .regression_group_equation_all import RegressionGroupEquationAll
from .regression_input_data import RegressionInputData
from .regression_input_data_all import RegressionInputDataAll
from .regression_model import RegressionModel
from .regression_model_all import RegressionModelAll
from .regression_variable import RegressionVariable
from .regression_variable_all import RegressionVariableAll
from .relative_uncertainty import RelativeUncertainty
from .relative_uncertainty_all import RelativeUncertaintyAll
from .rft_run_hdr import RftRunHdr
from .rgrid import Rgrid
from .rgrid_all import RgridAll
from .rig_info import RigInfo
from .scenario import Scenario
from .scenario_detail import ScenarioDetail
from .segment import Segment
from .seis_2d_line import Seis2DLine
from .seis_2d_storage_area import Seis2DStorageArea
from .seis_3d_survey import Seis3DSurvey
from .seis_geom_set_2d_line import SeisGeomSet2DLine
from .seis_geom_set_2d_survey import SeisGeomSet2DSurvey
from .seis_geom_set_3d_survey import SeisGeomSet3DSurvey
from .seis_prestack_dataset_remark import SeisPrestackDatasetRemark
from .seismic_2d_display_scale import Seismic2DDisplayScale
from .seismic_2d_location import Seismic2DLocation
from .seismic_3d_coverage_polygon import Seismic3DCoveragePolygon
from .seismic_3d_list import Seismic3DList
from .seismic_3d_list_member import Seismic3DListMember
from .seismic_change_log import SeismicChangeLog
from .seismic_data_set import SeismicDataSet
from .seismic_data_set_remark import SeismicDataSetRemark
from .seismic_data_set_v2 import SeismicDataSetV2
from .seismic_line_display import SeismicLineDisplay
from .seismic_list import SeismicList
from .seismic_list_detail import SeismicListDetail
from .seismic_list_member import SeismicListMember
from .seismic_other_fcl import SeismicOtherFcl
from .seismic_prestack_dataset import SeismicPrestackDataset
from .seismic_process import SeismicProcess
from .seismic_process_input import SeismicProcessInput
from .seismic_process_output import SeismicProcessOutput
from .seismic_process_parm import SeismicProcessParm
from .seismic_receiver_fcl import SeismicReceiverFcl
from .seismic_source_fcl import SeismicSourceFcl
from .seismic_streamer_fcl import SeismicStreamerFcl
from .seismograph_fcl import SeismographFcl
from .shape_node_property import ShapeNodeProperty
from .shift_hdr import ShiftHdr
from .shift_member import ShiftMember
from .soil_boring import SoilBoring
from .squeeze import Squeeze
from .strat_col import StratCol
from .strat_unit_summary import StratUnitSummary
from .structural_body import StructuralBody
from .structural_body_display import StructuralBodyDisplay
from .structural_model import StructuralModel
from .structural_model_all import StructuralModelAll
from .structural_model_body import StructuralModelBody
from .structural_model_body_all import StructuralModelBodyAll
from .structure_model_horizon import StructureModelHorizon
from .structure_model_horizon_all import StructureModelHorizonAll
from .surf_a_grp import SurfAGrp
from .surf_grmem import SurfGrmem
from .surf_key import SurfKey
from .surf_relation import SurfRelation
from .surface import Surface
from .surface_profile import SurfaceProfile
from .surface_profile_all import SurfaceProfileAll
from .surface_surface_contact import SurfaceSurfaceContact
from .surface_surface_contact_all import SurfaceSurfaceContactAll
from .survey_history import SurveyHistory
from .survey_tool import SurveyTool
from .survey_tool_term import SurveyToolTerm
from .synth_seis import SynthSeis
from .synth_seis2_d import SynthSeis2D
from .synthetic_horizon_data import SyntheticHorizonData
from .synthetic_hrzn_data_attribute import SyntheticHrznDataAttribute
from .synthetic_hrzn_data_remark import SyntheticHrznDataRemark
from .target import Target
from .target_all import TargetAll
from .target_estimator import TargetEstimator
from .target_estimator_all import TargetEstimatorAll
from .target_opt_parm import TargetOptParm
from .target_opt_parm_all import TargetOptParmAll
from .target_uncertainty import TargetUncertainty
from .target_uncertainty_all import TargetUncertaintyAll
from .targetting_configuration import TargettingConfiguration
from .td_info import TdInfo
from .texas_bh_location import TexasBHLocation
from .texas_surface_location import TexasSurfaceLocation
from .thumb_nail import ThumbNail
from .time_depth_table import TimeDepthTable
from .tool_coefficient import ToolCoefficient
from .tract_bndry import TractBndry
from .tract_offd import TractOffd
from .tubing import Tubing
from .tubing_equip import TubingEquip
from .turn_point import TurnPoint
from .turn_point_all import TurnPointAll
from .unique_seis_data_set_name import UniqueSeisDataSetName
from .unit import Unit
from .user_crv_default import UserCrvDefault
from .user_preferred_log_curve import UserPreferredLogCurve
from .vc_attribute_name import VcAttributeName
from .vc_contact_type import VcContactType
from .vc_cost import VcCost
from .vc_dipmeter_type import VcDipmeterType
from .vc_ecozone import VcEcozone
from .vc_field_type import VcFieldType
from .vc_genus import VcGenus
from .vc_intvl_type import VcIntvlType
from .vc_litho_class import VcLithoClass
from .vc_litho_crv_type import VcLithoCrvType
from .vc_log_crv_name import VcLogCrvName
from .vc_mineral import VcMineral
from .vc_pick_surf_name import VcPickSurfName
from .vc_species import VcSpecies
from .vc_strat_unit_name import VcStratUnitName
from .vc_survey_type import VcSurveyType
from .vc_well_study import VcWellStudy
from .vc_zone_name import VcZoneName
from .vertical_image_file import VerticalImageFile
from .volumetric_alys_result import VolumetricAlysResult
from .volumetric_analysis import VolumetricAnalysis
from .vsp_data_set import VspDataSet
from .vsp_geometry import VspGeometry
from .wp_target import WPTarget
from .wp_target_all import WPTargetAll
from .w_pdn_gas_anal import WPdnGasAnal
from .w_pdn_gas_anal_dtl import WPdnGasAnalDtl
from .w_pdn_oil_anal import WPdnOilAnal
from .w_pdn_oil_anal_dtl import WPdnOilAnalDtl
from .w_pdn_oil_visc import WPdnOilVisc
from .w_pdn_water_anal import WPdnWaterAnal
from .w_pdn_water_anal_dtl import WPdnWaterAnalDtl
from .wavelet import Wavelet
from .wavelet_filter_x import WaveletFilterX
from .well import Well
from .well_afe import WellAfe
from .well_bh_alternate_location import WellBHAlternateLocation
from .well_carter_loc import WellCarterLoc
from .well_completion import WellCompletion
from .well_congress_loc import WellCongressLoc
from .well_core import WellCore
from .well_core_anal_method import WellCoreAnalMethod
from .well_core_anal_remark import WellCoreAnalRemark
from .well_core_analysis import WellCoreAnalysis
from .well_core_description import WellCoreDescription
from .well_core_formation import WellCoreFormation
from .well_core_remark import WellCoreRemark
from .well_core_sample_anal import WellCoreSampleAnal
from .well_core_sample_desc import WellCoreSampleDesc
from .well_core_sample_property import WellCoreSampleProperty
from .well_core_sample_rmk import WellCoreSampleRmk
from .well_core_shift import WellCoreShift
from .well_date import WellDate
from .well_dls_loc import WellDlsLoc
from .well_dril_sum import WellDrilSum
from .well_entire import WellEntire
from .well_fault import WellFault
from .well_fluid_contact import WellFluidContact
from .well_fps_loc import WellFpsLoc
from .well_fracture_summary import WellFractureSummary
from .well_geodetic_loc import WellGeodeticLoc
from .well_header_alt import WellHeaderAlt
from .well_image import WellImage
from .well_interest import WellInterest
from .well_interest_scale import WellInterestScale
from .well_interval_display import WellIntervalDisplay
from .well_intvl import WellIntvl
from .well_intvl_val import WellIntvlVal
from .well_list import WellList
from .well_list_detail import WellListDetail
from .well_list_member import WellListMember
from .well_location import WellLocation
from .well_location_alt import WellLocationAlt
from .well_location_name_alt import WellLocationNameAlt
from .well_location_name_history import WellLocationNameHistory
from .well_location_remark import WellLocationRemark
from .well_location_uwi_alt import WellLocationUwiAlt
from .well_min_anal import WellMinAnal
from .well_mineral_perc import WellMineralPerc
from .well_name_alt import WellNameAlt
from .well_name_history import WellNameHistory
from .well_narrative_loc import WellNarrativeLoc
from .well_northeast_loc import WellNortheastLoc
from .well_northsea_loc import WellNorthseaLoc
from .well_note_pad import WellNotePad
from .well_nts_loc import WellNtsLoc
from .well_ocs_loc import WellOcsLoc
from .well_ohio_loc import WellOhioLoc
from .well_operator import WellOperator
from .well_pdm_daily_injection import WellPdmDailyInjection
from .well_pdm_daily_prod import WellPdmDailyProd
from .well_pdm_econ_detail import WellPdmEconDetail
from .well_pdm_econ_monthly import WellPdmEconMonthly
from .well_pdm_econ_oneline import WellPdmEconOneline
from .well_pdm_facility_group import WellPdmFacilityGroup
from .well_pdm_group_alloc import WellPdmGroupAlloc
from .well_pdm_monthly_injection import WellPdmMonthlyInjection
from .well_pdm_monthly_prod import WellPdmMonthlyProd
from .well_pdm_monthly_prod_short import WellPdmMonthlyProdShort
from .well_pdm_prod_cums import WellPdmProdCums
from .well_perforation import WellPerforation
from .well_plan import WellPlan
from .well_plan_all import WellPlanAll
from .well_plan_interval import WellPlanInterval
from .well_plan_interval_all import WellPlanIntervalAll
from .well_plan_proj import WellPlanProj
from .well_plan_proj_all import WellPlanProjAll
from .well_plan_project_opt_parm import WellPlanProjectOptParm
from .well_planning_group import WellPlanningGroup
from .well_pressure import WellPressure
from .well_pressure_aof import WellPressureAOF
from .well_pressure_aof4_pt import WellPressureAOF4PT
from .well_pressure_bh import WellPressureBH
from .well_prod_interest import WellProdInterest
from .well_prod_zone import WellProdZone
from .well_remark import WellRemark
from .well_short import WellShort
from .well_sieve_anal import WellSieveAnal
from .well_sieve_scrn import WellSieveScrn
from .well_status_history import WellStatusHistory
from .well_study import WellStudy
from .well_surface_alt_location import WellSurfaceAltLocation
from .well_survey import WellSurvey
from .well_template import WellTemplate
from .well_test import WellTest
from .well_test_anal import WellTestAnal
from .well_test_cont import WellTestCont
from .well_test_cush import WellTestCush
from .well_test_equip import WellTestEquip
from .well_test_flow import WellTestFlow
from .well_test_mud import WellTestMud
from .well_test_per import WellTestPer
from .well_test_press import WellTestPress
from .well_test_rec import WellTestRec
from .well_test_recov import WellTestRecov
from .well_test_remark import WellTestRemark
from .well_test_shut import WellTestShut
from .well_texas_loc import WellTexasLoc
from .well_treatment import WellTreatment
from .well_tst_comp_anal import WellTstCompAnal
from .well_tst_flw_meas import WellTstFlwMeas
from .well_tst_pres_meas import WellTstPresMeas
from .well_uwi import WellUwi
from .well_work_over import WellWorkOver
from .well_z_conversion import WellZConversion
from .x_sec_anno import XSecAnno
from .x_sec_anno_all import XSecAnnoAll
from .xs_well import XsWell
from .xs_well_all import XsWellAll
from .xyz_function import XyzFunction
from .xyz_function_property import XyzFunctionProperty
from .xyz_function_set import XyzFunctionSet
from .z_domain_qualifier import ZDomainQualifier
from .zone_attribute import ZoneAttribute
from .zone_mng_z_attr import ZoneMngZAttr
from .zone_mng_zone import ZoneMngZone
from .zone_mng_zone_z_attr import ZoneMngZoneZAttr
from .columns import Columns
from .data_types import DataTypes
from .function_params import FunctionParams
from .functions import Functions
from .geography_columns import GeographyColumns
from .geometry_columns import GeometryColumns
from .key_columns import KeyColumns
from .keys import Keys
from .procedure_params import ProcedureParams
from .procedures import Procedures
from .properties import Properties
from .reference_key_columns import ReferenceKeyColumns
from .schemas import Schemas
from .tables import Tables
from .virtual_databases import VirtualDatabases
from .spatial_ref_sys import SpatialRefSys
from .mat_views import MatViews
from .requests import REQUESTS
from .sessions import SESSIONS
from .stored_procedures import StoredProcedures
from .transactions import TRANSACTIONS
from .triggers import Triggers
from .usage import Usage
from .vdb_resources import VDBResources
from .views import Views
from .columns import Columns
from .key_column_usage import KeyColumnUsage
from .referential_constraints import ReferentialConstraints
from .table_constraints import TableConstraints
from .tables import Tables
from .views import Views
from .matpg_datatype import MatpgDatatype
from .pg_am import PgAm
from .pg_attrdef import PgAttrdef
from .pg_attribute import PgAttribute
from .pg_class import PgClass
from .pg_constraint import PgConstraint
from .pg_database import PgDatabase
from .pg_description import PgDescription
from .pg_index import PgIndex
from .pg_inherits import PgInherits
from .pg_namespace import PgNamespace
from .pg_prepared_xacts import PgPreparedXacts
from .pg_proc import PgProc
from .pg_rewrite import PgRewrite
from .pg_roles import PgRoles
from .pg_stats import PgStats
from .pg_tables import PgTables
from .pg_tablespace import PgTablespace
from .pg_trigger import PgTrigger
from .pg_type import PgType
from .pg_user import PgUser

__all__ = [
    "BaseModel",
    "Activity", "AnalysisLogUse", "AnalysisParmUse", "AppCordTrfm", "ApplicationData", "ApplicationTextData", "Baseline", "BaselineAll", "Basin", "BasinBoundary", "BinsetGrid2DShptTrace", "BinsetGrid3DGrid", "BitRecord", "BlowOut", "BodyFaultContact", "BodyFaultContactAll", "BodySurfaceContact", "BodySurfaceContactAll", "CalcLith", "CalcLithHead", "CarterBHLocation", "CarterSurfaceLocation", "CartoRefSys", "Casing", "ClipPolygon", "ClipPolygonAll", "CntrLine", "CntrLineAll", "CntrParm", "CntrParmAll", "CntrSet", "CntrSetAll", "CongressBHLocation", "CongressSurfaceLocation", "ControlPoint", "CoordinateSys", "CoordinateTrfm", "CordTrfmMth", "CordTrfmPar", "CordTrfmVal", "CorePropertyAlys", "CorePropertyAlysDetail", "Cost", "CountryBasin", "CrossSection", "CrossSectionAll", "CrvBackup", "CrvSummation", "CrvSummationMember", "CrvTemplate", "CurveHistRmk", "CurveMnemonicGroup", "CurveMnemonicGroupMember", "DSSession", "DSSessionEditor", "DSSessionFolder", "DSSessionProject", "DSTemplate", "DailyActivity", "DailySummary", "DataDictValue", "DataDictionary", "DataSrc", "DataSrcUser", "Dipmeter", "DirSurvey", "DlsBHLocation", "DlsSurfaceLocation", "DrilgLog", "DrillPump", "DrillersEstimatorPt", "DrillersEstimatorPtAll", "DrillingObj", "DstJobHdr", "DstRftCush", "DstRftFluid", "DstRftGen", "DstRftMatSurf", "DstRftPress", "DstRftSummary", "EarthModelStudy", "EarthModelStudyAll", "EcoPhase", "EconOutputConfig", "EconStreamType", "ElevInfo", "Ellipsoid", "EmBodySurfaceContact", "EmBodySurfaceContactAll", "EmCleaningRadius", "EmCleaningRadiusAll", "EmCompartment", "EmCompartmentAll", "EmCompartmentModel", "EmCompartmentModelAll", "EmCompartmentPatch", "EmCompartmentPatchAll", "EmContour", "EmContourAll", "EmCrossSection", "EmCrossSectionAll", "EmCrossSectionSurface", "EmCrossSectionSurfaceAll", "EmFault", "EmFaultAll", "EmFaultFaultContact", "EmFaultFaultContactAll", "EmFaultSurfaceContact", "EmFaultSurfaceContactAll", "EmFluidContact", "EmFluidContactAll", "EmFluidContactProspect", "EmFluidContactProspectAll", "EmHorizon", "EmHorizonAll", "EmIsochoreConstraint", "EmIsochoreConstraintAll", "EmKriging", "EmKrigingAll", "EmLayerDefinition", "EmLayerDefinitionAll", "EmMissingTop", "EmMissingTopAll", "EmObjectInput", "EmObjectInputAll", "EmPropertyMap", "EmPropertyMapAll", "EmProspect", "EmProspectAll", "EmProspectTermFault", "EmProspectTermFaultAll", "EmPtyMapDiscontinuity", "EmPtyMapDiscontinuityAll", "EmPtyMapLinrBdryFunc", "EmPtyMapLinrBdryFuncAll", "EmRestoredTop", "EmRestoredTopAll", "EmStructuralBody", "EmStructuralBodyAll", "EmStructuralModel", "EmStructuralModelAll", "EmSurfaceSurfaceContact", "EmSurfaceSurfaceContactAll", "EmVerticalCpg", "EmVerticalCpgAll", "EmVerticalCpgReservoir", "EmVerticalCpgReservoirAll", "ExplorationPlay", "ExtStorage", "ExternalDataObject", "Fault", "FaultCenterLine", "FaultCenterLineAll", "FaultCenterLineSet", "FaultCenterLineSetAll", "FaultCut", "FaultCutAll", "FaultDisplay", "FaultFaultContact", "FaultFaultContactAll", "FaultHeave", "FaultList", "FaultListMember", "FaultNetwork", "FaultNetworkAll", "FaultNetworkFault", "FaultNetworkFaultAll", "FaultPlane", "FaultPlaneRemark", "FaultPlaneTrimesh", "FaultPointSet", "FaultPointSetAll", "FaultPolygon", "FaultPolygonAll", "FaultPolygonSet", "FaultPolygonSetAll", "FaultProfile", "FaultProfileAll", "FaultSegment", "FaultSurf", "FaultSurfAll", "FaultSurfaceContact", "FaultSurfaceContactAll", "FaultTrimesh", "Fgrid", "FgridAll", "FieldBoundary", "FieldList", "FieldListMember", "FieldPros", "FieldProsInt", "FieldProspectInterestScale", "FillTemplate", "FpsBHLocation", "FpsSurfaceLocation", "FracNetPropSetMember", "FracNetPropSetMemberAll", "FracNetProperty", "FracNetPropertyAll", "FracNetPropertySet", "FracNetPropertySetAll", "FracTreatmentFormation", "FracWellProperty", "Fracture", "FractureAll", "FractureJobFracWell", "FractureNetwork", "FractureNetworkAll", "FractureNetworkSlice", "FractureNetworkSliceAll", "FractureNetworkSliceV2", "FractureNetworkSliceV2All", "FracturePick", "FracturePickAll", "FracturePickV", "FractureProperty", "FracturePropertyAll", "FractureSurfaceGeometry", "FractureSurfaceGeometryAll", "FractureSurfaceProperty", "FractureSurfacePropertyAll", "FractureSurfaceVolume", "FractureSurfaceVolumeAll", "FractureTrace", "FractureTraceAll", "FunctionAttribute", "FunctionSetAttribute", "GeoArea", "GeoShapeAttribute", "GeoShapeSet", "GeoShapeSetAttribute", "GeodeticBHLocation", "GeodeticDatum", "GeodeticSurfaceLocation", "GeologicalEstimatorPt", "GeologicalEstimatorPtAll", "GeopAcqArea", "GeoreferencedImageCatalog", "GgxCrvCmd", "GgxCrvSet", "GgxCrvSetCmd", "GgxKeyFldLookUp", "GgxKeyTblLookUp", "GgxSchemaVer", "GgxSurfGuidingPts", "GgxWellMetadata", "Grid", "Grid3D", "Grid3DAll", "Grid3DInterval", "Grid3DIntervalAll", "Grid3DLayering", "Grid3DLayeringAll", "GridAll", "GridList", "GridListMember", "GridRegion", "GridSet", "GridSetMember", "GridSetRegion", "Gridded3DVolume", "Gridded3DVolumeAll", "GxFaultFieldPt", "GxStratFieldSection", "GxWellLogAnn", "Histogram", "Horizon2DAttribute", "HorizonAttributeCatalog", "HorizonAttributeHdr", "HorizonAttributeRemark", "HorizonBodyCleaningArea", "HorizonBodyCleaningAreaAll", "HorizonCatalog", "HorizonChangeLog", "HorizonCleaningArea", "HorizonCleaningAreaAll", "HorizonData", "HorizonDataRemark", "HorizonListHeader", "HorizonListMember", "HorizonParms", "HorizonPatch", "HorizonPatchAll", "HorizonPolygonSetUsage", "HorizonZLayerAttr", "HorizonZLayerData", "HwcInterpControlPt", "HwcInterpPredictedCurve", "HwcInterpTypeLogSetting", "HwcInterpretation", "HwcInterpretationPref", "Hybrid3DVolume", "Hybrid3DVolumeAttribute", "I3DV", "I3DVAll", "I3DVData", "I3DVDataAll", "IGeometry", "IGeometryAll", "INoteClassification", "INoteDocument", "INoteDocumentLink", "INoteImage", "INoteImageSymbol", "INoteListHdr", "INoteListMember", "INoteQuery", "INoteSummary", "INoteTextBlock", "IRPoints", "IRPointsAll", "ISetCategory", "ISetDataObject", "ISetDynamicQuery", "ISetFolder", "ISetProperty", "ISetTemplate", "ISetTemplateFolder", "ISetTemplateObjType", "InterWellAttribute", "Interest", "InterestScale", "InterpListMember", "InterpPriorityList", "InterpPrj3DSeismic", "InterpPrjAOI", "InterpProcessInput", "InterpProcessOutput", "InterpProcessParm", "InterpretationNote", "InterpretationProcess", "InterpretationProject", "InterpretationSet", "InterpretationStudy", "IntrpDrilgShow", "KaLinks", "KaResults", "KaSymbols", "KeyWell", "Lease", "LeaseComm", "LeaseFieldPros", "LeaseInterestScale", "LeaseList", "LeaseListMember", "LeaseNarrative", "LeaseTract", "Lessee", "Lessor", "LicenseRnd", "LineSegment", "LineSegmentAll", "Liner", "LithotypeFacies", "LocRemark", "LockedWellAttribute", "LockedWellCategory", "LockedWellLocnAttribute", "LockedWellLocnCategory", "LogCrvList", "LogCrvListMember", "LogCurve", "LogCurveQualifier", "LogCurveStruct", "LogCurveStructured", "LogImageAlias", "LogImageAliasGroup", "LogImageRegLogSection", "LogImageUnregImage", "LogSampleBlockInfo", "LogSampleFramework", "LogTraceAnalysis", "LoggingJob", "LoggingMudTest", "LoggingSensorParm", "LoggingTool", "LoggingToolCalib", "LoggingToolConfig", "LoggingToolEquipment", "LoggingToolParm", "LoggingToolPass", "LoggingToolService", "LoggingToolStringDescent", "LostCirc", "MWDRun", "MapDataHist", "MappingPolySet", "MappingPolySetAll", "MappingPolygon", "MappingPolygonAll", "MdmMimeApplication", "MdmMimeType", "MeasSystemMember", "MeasUnitTypeMember", "MeasurementSystem", "MeasurementUnit", "MeasurementUnitType", "MicroseismicEventProperty", "MicroseismicJob", "MicroseismicMonitorWell", "MicroseismicStage", "MicroseismicVolAlysParm", "MicroseismicVolAlysStage", "MicroseismicVolumetricAlys", "MistieFunctionHdr", "MistieFunctionMember", "MudReport", "MudlogDesc", "MudlogHdr", "NarrativeSurfaceLocation", "NaturalFracturePick", "NominalSeismicGeometry", "NorthSeaBHLocation", "NorthSeaSurfaceLocation", "NortheastBHLocation", "NortheastSurfaceLocation", "NtsBHLocation", "NtsSurfaceLocation", "OcsBHLocation", "OcsSurfaceLocation", "OhioBHLocation", "OhioSurfaceLocation", "OwDataLockValue", "OwDbDataFileDir", "OwQuery", "OwQueryDef", "OwQueryName", "OwSavedQuery", "OwsysDatumShiftDefaults", "OwsysInterpretationPrj", "OwsysPrjUser", "OwsysProject", "OwsysUser", "Packer", "Paleo", "PaleoSampleAnalysis", "PaleoSampleAnalysisDetail", "PcaFactorData", "PcaFactorDataAll", "PcaInputData", "PcaInputDataAll", "PdenGasAnal", "PdenGasAnalDtl", "PdenHdr", "PdenOilAnal", "PdenOilAnalDtl", "PdenOilVisc", "PdenWaterAnal", "PdenWaterAnalDtl", "PdmDailyInjection", "PdmDailyProd", "PdmEconDetail", "PdmEconMonthly", "PdmEconOneline", "PdmFacilityGroup", "PdmGroupAlloc", "PdmMonthlyInjection", "PdmMonthlyProd", "PdmProdCums", "PetrophysicalParmValue", "Pick", "PlanOptParm", "PlanOptParmAll", "PlanParameter", "PlanParameterSet", "PlatformInfo", "PlatformSlot", "Plugging", "PointSet", "PointSetAll", "PointSetComposite", "PointSetCompositeAll", "PointSetField", "PointSetFieldAll", "PointSetLithotype", "PointSetRegion", "PolyParameter", "PolyParameterAll", "Pool", "PoolFluidContact", "PoolVolAnal", "PoolVolume", "PosLog", "PrefWellZConversion", "PreferredShiftSet", "PreferredSynthetic", "PreferredSynthetic2D", "PreferredTDCurve", "PrestackHorizonData", "PrestackHorizonHdr", "PrestackHrznDataAttribute", "PrestackHrznDataRemark", "PrestackHrznHdrRemark", "PrimeMeridian", "PrincipalComponentAnalysis", "PrincipalComponentAnalysisAll", "ProcessDataType", "ProdFacility", "ProdInterest", "ProjDBUser", "ProjRemark", "ProjRemarkType", "ProjUser", "Project", "ProjectAll", "ProjectExtension", "RAlias", "RAnalysisVersion", "RBasinType", "RBinaryDataFmt", "RBoreholeType", "RCommType", "RCompany", "RCordSysCstr", "RCordTrfm", "RCordTrfmPar", "RCoreAnalysisType", "RCoreProperty", "RCountry", "RCountyName", "RCurrency", "RCurveType", "RDataAcqType", "RDataType", "RDigitalFmt", "RDiscBasis", "RDistributionType", "REOMDown", "RElementOrientation", "REmProperty", "RFaultPlaneRmkType", "RFieldProsStat", "RFluidAnalProp", "RFractureNetworkProperty", "RFractureProperty", "RFunctionAttribute", "RFunctionProperty", "RFunctionSetAttribute", "RFunctionSetCategory", "RGainMode", "RGeodeticSource", "RGeologicFeature", "RGeometry", "RGeometryAll", "RHorizonAttribute", "RHorizonAttributeRmkType", "RHorizonClass", "RHorizonDataRmkType", "RHorizonName", "RINoteDataObjType", "RImageLogName", "RImageType", "RInterestType", "RInterpStudyPhase", "RInterpStudyType", "RInterpretationStatus", "RInterpretationVersion", "RLeaseEvent", "RLockDataCategory", "RLogPassType", "RLogQualifier", "RLoggingEquipType", "RLoggingSensorParm", "RLoggingService", "RLoggingToolParm", "RMapProj", "RMicroseismicAlysParm", "RMicroseismicEventPty", "RMicroseismicSrvMethod", "RMineralAnalysisType", "RNarrType", "ROptParameter", "RPaleoAnalysisType", "RPaleoComponent", "RParameterAtr", "RParmRelatnType", "RParmType", "RPetroActType", "RPetroParmName", "RPlayCategory", "RPolyParm", "RPositionType", "RPrestackHrznDataRmkType", "RPrestackHrznHdrRmkType", "RPriorityListCategory", "RProcessIOType", "RProcessParm", "RProcessType", "RProdType", "RPropertySet", "RProposalType", "RRecPos", "RRecType", "RRushCat", "RSampleFormat", "RSeisPickOnset", "RSeisPrestackDatatype", "RSeisPrestackRmkType", "RSeisZType", "RSeismicAttribute", "RSeismicClass", "RSeismicDataSetRmkType", "RSeismicGeometry", "RSeismicPolarity", "RSeismicVersion", "RSeismicVibratorSweep", "RShapeAttribute", "RShapeSetAttribute", "RShapeSetType", "RSpread", "RSqueezeTestType", "RStateName", "RSurveyEnvironment", "RSynHrznDataRmkType", "RSynthetic2DType", "RSyntheticType", "RTargetType", "RTestPerType", "RTestRecov", "RTestRecovMeth", "RTestRes", "RTestSubtype", "RTrajectoryShape", "RTrfmCstr", "RVelocityModelAttribute", "RVolumeCategory", "RVolumeStatus", "RVspDataSetType", "RVspGeometryType", "RWPIntervalType", "RWaveFilt", "RWaveFiltAlgr", "RWaveform", "RWellClass", "RWellDateType", "RWellNameType", "RWellStatus", "RWellTestPurpose", "RWellTestType", "RZLayerType", "RegressionEquation", "RegressionEquationAll", "RegressionFactor", "RegressionFactorAll", "RegressionGroup", "RegressionGroupAll", "RegressionGroupEquation", "RegressionGroupEquationAll", "RegressionInputData", "RegressionInputDataAll", "RegressionModel", "RegressionModelAll", "RegressionVariable", "RegressionVariableAll", "RelativeUncertainty", "RelativeUncertaintyAll", "RftRunHdr", "Rgrid", "RgridAll", "RigInfo", "Scenario", "ScenarioDetail", "Segment", "Seis2DLine", "Seis2DStorageArea", "Seis3DSurvey", "SeisGeomSet2DLine", "SeisGeomSet2DSurvey", "SeisGeomSet3DSurvey", "SeisPrestackDatasetRemark", "Seismic2DDisplayScale", "Seismic2DLocation", "Seismic3DCoveragePolygon", "Seismic3DList", "Seismic3DListMember", "SeismicChangeLog", "SeismicDataSet", "SeismicDataSetRemark", "SeismicDataSetV2", "SeismicLineDisplay", "SeismicList", "SeismicListDetail", "SeismicListMember", "SeismicOtherFcl", "SeismicPrestackDataset", "SeismicProcess", "SeismicProcessInput", "SeismicProcessOutput", "SeismicProcessParm", "SeismicReceiverFcl", "SeismicSourceFcl", "SeismicStreamerFcl", "SeismographFcl", "ShapeNodeProperty", "ShiftHdr", "ShiftMember", "SoilBoring", "Squeeze", "StratCol", "StratUnitSummary", "StructuralBody", "StructuralBodyDisplay", "StructuralModel", "StructuralModelAll", "StructuralModelBody", "StructuralModelBodyAll", "StructureModelHorizon", "StructureModelHorizonAll", "SurfAGrp", "SurfGrmem", "SurfKey", "SurfRelation", "Surface", "SurfaceProfile", "SurfaceProfileAll", "SurfaceSurfaceContact", "SurfaceSurfaceContactAll", "SurveyHistory", "SurveyTool", "SurveyToolTerm", "SynthSeis", "SynthSeis2D", "SyntheticHorizonData", "SyntheticHrznDataAttribute", "SyntheticHrznDataRemark", "Target", "TargetAll", "TargetEstimator", "TargetEstimatorAll", "TargetOptParm", "TargetOptParmAll", "TargetUncertainty", "TargetUncertaintyAll", "TargettingConfiguration", "TdInfo", "TexasBHLocation", "TexasSurfaceLocation", "ThumbNail", "TimeDepthTable", "ToolCoefficient", "TractBndry", "TractOffd", "Tubing", "TubingEquip", "TurnPoint", "TurnPointAll", "UniqueSeisDataSetName", "Unit", "UserCrvDefault", "UserPreferredLogCurve", "VcAttributeName", "VcContactType", "VcCost", "VcDipmeterType", "VcEcozone", "VcFieldType", "VcGenus", "VcIntvlType", "VcLithoClass", "VcLithoCrvType", "VcLogCrvName", "VcMineral", "VcPickSurfName", "VcSpecies", "VcStratUnitName", "VcSurveyType", "VcWellStudy", "VcZoneName", "VerticalImageFile", "VolumetricAlysResult", "VolumetricAnalysis", "VspDataSet", "VspGeometry", "WPTarget", "WPTargetAll", "WPdnGasAnal", "WPdnGasAnalDtl", "WPdnOilAnal", "WPdnOilAnalDtl", "WPdnOilVisc", "WPdnWaterAnal", "WPdnWaterAnalDtl", "Wavelet", "WaveletFilterX", "Well", "WellAfe", "WellBHAlternateLocation", "WellCarterLoc", "WellCompletion", "WellCongressLoc", "WellCore", "WellCoreAnalMethod", "WellCoreAnalRemark", "WellCoreAnalysis", "WellCoreDescription", "WellCoreFormation", "WellCoreRemark", "WellCoreSampleAnal", "WellCoreSampleDesc", "WellCoreSampleProperty", "WellCoreSampleRmk", "WellCoreShift", "WellDate", "WellDlsLoc", "WellDrilSum", "WellEntire", "WellFault", "WellFluidContact", "WellFpsLoc", "WellFractureSummary", "WellGeodeticLoc", "WellHeaderAlt", "WellImage", "WellInterest", "WellInterestScale", "WellIntervalDisplay", "WellIntvl", "WellIntvlVal", "WellList", "WellListDetail", "WellListMember", "WellLocation", "WellLocationAlt", "WellLocationNameAlt", "WellLocationNameHistory", "WellLocationRemark", "WellLocationUwiAlt", "WellMinAnal", "WellMineralPerc", "WellNameAlt", "WellNameHistory", "WellNarrativeLoc", "WellNortheastLoc", "WellNorthseaLoc", "WellNotePad", "WellNtsLoc", "WellOcsLoc", "WellOhioLoc", "WellOperator", "WellPdmDailyInjection", "WellPdmDailyProd", "WellPdmEconDetail", "WellPdmEconMonthly", "WellPdmEconOneline", "WellPdmFacilityGroup", "WellPdmGroupAlloc", "WellPdmMonthlyInjection", "WellPdmMonthlyProd", "WellPdmMonthlyProdShort", "WellPdmProdCums", "WellPerforation", "WellPlan", "WellPlanAll", "WellPlanInterval", "WellPlanIntervalAll", "WellPlanProj", "WellPlanProjAll", "WellPlanProjectOptParm", "WellPlanningGroup", "WellPressure", "WellPressureAOF", "WellPressureAOF4PT", "WellPressureBH", "WellProdInterest", "WellProdZone", "WellRemark", "WellShort", "WellSieveAnal", "WellSieveScrn", "WellStatusHistory", "WellStudy", "WellSurfaceAltLocation", "WellSurvey", "WellTemplate", "WellTest", "WellTestAnal", "WellTestCont", "WellTestCush", "WellTestEquip", "WellTestFlow", "WellTestMud", "WellTestPer", "WellTestPress", "WellTestRec", "WellTestRecov", "WellTestRemark", "WellTestShut", "WellTexasLoc", "WellTreatment", "WellTstCompAnal", "WellTstFlwMeas", "WellTstPresMeas", "WellUwi", "WellWorkOver", "WellZConversion", "XSecAnno", "XSecAnnoAll", "XsWell", "XsWellAll", "XyzFunction", "XyzFunctionProperty", "XyzFunctionSet", "ZDomainQualifier", "ZoneAttribute", "ZoneMngZAttr", "ZoneMngZone", "ZoneMngZoneZAttr", "Columns", "DataTypes", "FunctionParams", "Functions", "GeographyColumns", "GeometryColumns", "KeyColumns", "Keys", "ProcedureParams", "Procedures", "Properties", "ReferenceKeyColumns", "Schemas", "Tables", "VirtualDatabases", "SpatialRefSys", "MatViews", "REQUESTS", "SESSIONS", "StoredProcedures", "TRANSACTIONS", "Triggers", "Usage", "VDBResources", "Views", "Columns", "KeyColumnUsage", "ReferentialConstraints", "TableConstraints", "Tables", "Views", "MatpgDatatype", "PgAm", "PgAttrdef", "PgAttribute", "PgClass", "PgConstraint", "PgDatabase", "PgDescription", "PgIndex", "PgInherits", "PgNamespace", "PgPreparedXacts", "PgProc", "PgRewrite", "PgRoles", "PgStats", "PgTables", "PgTablespace", "PgTrigger", "PgType", "PgUser"
]
